import * as cdk from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { Cur2ContentOptions, Cur2DeliveryOptions } from './data-export-definition.types';
import { ReportDefinitionOptions } from './report-definition.types';
export interface CurStackProps extends cdk.StackProps, ReportDefinitionOptions {
    /**
     * The name of the report that you want to create.
     * The name must be unique, is case sensitive, and can't include spaces.
     *
     */
    readonly reportName: string;
    /**
     * The S3 bucket where AWS delivers the report - defaults to a new bucket named `cur-${ACCOUNT_ID}-${REGION}`
     *    Length Constraints: Maximum length of 256.
     *    Pattern: [A-Za-z0-9_\.\-]+
     *
     */
    readonly s3Bucket?: cdk.aws_s3.IBucket;
}
export declare class CurStack extends cdk.Stack {
    constructor(scope: Construct, id: string, props: CurStackProps);
}
export interface Cur2StackProps extends cdk.StackProps, Cur2ContentOptions, Cur2DeliveryOptions {
    /**
     * The name of this specific data export.
     */
    readonly name: string | undefined;
    /**
     * The description for this specific data export.
     */
    readonly exportDescription?: string;
    /**
     * The S3 bucket where your data export will be stored.
     *    Length Constraints: Maximum length of 256.
     *    Pattern: [A-Za-z0-9_\.\-]+
     *
     */
    readonly bucket?: cdk.aws_s3.IBucket;
    /**
     * The prefix that AWS adds to the report name when AWS delivers the report. Your prefix can't include spaces.
     *    Length Constraints: Maximum length of 256.
     *    Pattern: [A-Za-z0-9_\.\-]*
     *
     * @default ""
     *
     */
    readonly s3Prefix?: string;
}
export declare class Cur2Stack extends cdk.Stack {
    constructor(scope: Construct, id: string, props: Cur2StackProps);
}
