import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { BCMDataExportsClientResolvedConfig } from "../BCMDataExportsClient";
/**
 * @internal
 */
export interface BCMDataExportsHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface BCMDataExportsHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<BCMDataExportsClientResolvedConfig, HandlerExecutionContext, BCMDataExportsHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultBCMDataExportsHttpAuthSchemeParametersProvider: (config: BCMDataExportsClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<BCMDataExportsHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface BCMDataExportsHttpAuthSchemeProvider extends HttpAuthSchemeProvider<BCMDataExportsHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultBCMDataExportsHttpAuthSchemeProvider: BCMDataExportsHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: BCMDataExportsHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: BCMDataExportsHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
