import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { BCMDataExportsServiceException as __BaseException } from "./BCMDataExportsServiceException";
export interface DataQuery {
  QueryStatement: string | undefined;
  TableConfigurations?: Record<string, Record<string, string>>;
}
export declare const CompressionOption: {
  readonly GZIP: "GZIP";
  readonly PARQUET: "PARQUET";
};
export type CompressionOption =
  (typeof CompressionOption)[keyof typeof CompressionOption];
export declare const FormatOption: {
  readonly PARQUET: "PARQUET";
  readonly TEXT_OR_CSV: "TEXT_OR_CSV";
};
export type FormatOption = (typeof FormatOption)[keyof typeof FormatOption];
export declare const S3OutputType: {
  readonly CUSTOM: "CUSTOM";
};
export type S3OutputType = (typeof S3OutputType)[keyof typeof S3OutputType];
export declare const OverwriteOption: {
  readonly CREATE_NEW_REPORT: "CREATE_NEW_REPORT";
  readonly OVERWRITE_REPORT: "OVERWRITE_REPORT";
};
export type OverwriteOption =
  (typeof OverwriteOption)[keyof typeof OverwriteOption];
export interface S3OutputConfigurations {
  OutputType: S3OutputType | undefined;
  Format: FormatOption | undefined;
  Compression: CompressionOption | undefined;
  Overwrite: OverwriteOption | undefined;
}
export interface S3Destination {
  S3Bucket: string | undefined;
  S3Prefix: string | undefined;
  S3Region: string | undefined;
  S3OutputConfigurations: S3OutputConfigurations | undefined;
}
export interface DestinationConfigurations {
  S3Destination: S3Destination | undefined;
}
export declare const FrequencyOption: {
  readonly SYNCHRONOUS: "SYNCHRONOUS";
};
export type FrequencyOption =
  (typeof FrequencyOption)[keyof typeof FrequencyOption];
export interface RefreshCadence {
  Frequency: FrequencyOption | undefined;
}
export interface Export {
  ExportArn?: string;
  Name: string | undefined;
  Description?: string;
  DataQuery: DataQuery | undefined;
  DestinationConfigurations: DestinationConfigurations | undefined;
  RefreshCadence: RefreshCadence | undefined;
}
export interface ResourceTag {
  Key: string | undefined;
  Value: string | undefined;
}
export interface CreateExportRequest {
  Export: Export | undefined;
  ResourceTags?: ResourceTag[];
}
export interface CreateExportResponse {
  ExportArn?: string;
}
export declare class InternalServerException extends __BaseException {
  readonly name: "InternalServerException";
  readonly $fault: "server";
  Message: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InternalServerException, __BaseException>
  );
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  Message: string | undefined;
  ResourceId?: string;
  ResourceType?: string;
  QuotaCode: string | undefined;
  ServiceCode: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export declare class ThrottlingException extends __BaseException {
  readonly name: "ThrottlingException";
  readonly $fault: "client";
  Message: string | undefined;
  QuotaCode?: string;
  ServiceCode?: string;
  constructor(
    opts: __ExceptionOptionType<ThrottlingException, __BaseException>
  );
}
export interface ValidationExceptionField {
  Name: string | undefined;
  Message: string | undefined;
}
export declare const ValidationExceptionReason: {
  readonly CANNOT_PARSE: "cannotParse";
  readonly FIELD_VALIDATION_FAILED: "fieldValidationFailed";
  readonly OTHER: "other";
  readonly UNKNOWN_OPERATION: "unknownOperation";
};
export type ValidationExceptionReason =
  (typeof ValidationExceptionReason)[keyof typeof ValidationExceptionReason];
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  Message: string | undefined;
  Reason?: ValidationExceptionReason;
  Fields?: ValidationExceptionField[];
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface DeleteExportRequest {
  ExportArn: string | undefined;
}
export interface DeleteExportResponse {
  ExportArn?: string;
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  Message: string | undefined;
  ResourceId: string | undefined;
  ResourceType: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export interface GetExecutionRequest {
  ExportArn: string | undefined;
  ExecutionId: string | undefined;
}
export declare const ExecutionStatusCode: {
  readonly DELIVERY_FAILURE: "DELIVERY_FAILURE";
  readonly DELIVERY_IN_PROCESS: "DELIVERY_IN_PROCESS";
  readonly DELIVERY_SUCCESS: "DELIVERY_SUCCESS";
  readonly INITIATION_IN_PROCESS: "INITIATION_IN_PROCESS";
  readonly QUERY_FAILURE: "QUERY_FAILURE";
  readonly QUERY_IN_PROCESS: "QUERY_IN_PROCESS";
  readonly QUERY_QUEUED: "QUERY_QUEUED";
};
export type ExecutionStatusCode =
  (typeof ExecutionStatusCode)[keyof typeof ExecutionStatusCode];
export declare const ExecutionStatusReason: {
  readonly BILL_OWNER_CHANGED: "BILL_OWNER_CHANGED";
  readonly INSUFFICIENT_PERMISSION: "INSUFFICIENT_PERMISSION";
  readonly INTERNAL_FAILURE: "INTERNAL_FAILURE";
};
export type ExecutionStatusReason =
  (typeof ExecutionStatusReason)[keyof typeof ExecutionStatusReason];
export interface ExecutionStatus {
  StatusCode?: ExecutionStatusCode;
  StatusReason?: ExecutionStatusReason;
  CreatedAt?: Date;
  CompletedAt?: Date;
  LastUpdatedAt?: Date;
}
export interface GetExecutionResponse {
  ExecutionId?: string;
  Export?: Export;
  ExecutionStatus?: ExecutionStatus;
}
export interface GetExportRequest {
  ExportArn: string | undefined;
}
export declare const ExportStatusCode: {
  readonly HEALTHY: "HEALTHY";
  readonly UNHEALTHY: "UNHEALTHY";
};
export type ExportStatusCode =
  (typeof ExportStatusCode)[keyof typeof ExportStatusCode];
export interface ExportStatus {
  StatusCode?: ExportStatusCode;
  StatusReason?: ExecutionStatusReason;
  CreatedAt?: Date;
  LastUpdatedAt?: Date;
  LastRefreshedAt?: Date;
}
export interface GetExportResponse {
  Export?: Export;
  ExportStatus?: ExportStatus;
}
export interface GetTableRequest {
  TableName: string | undefined;
  TableProperties?: Record<string, string>;
}
export interface Column {
  Name?: string;
  Type?: string;
  Description?: string;
}
export interface GetTableResponse {
  TableName?: string;
  Description?: string;
  TableProperties?: Record<string, string>;
  Schema?: Column[];
}
export interface ListExecutionsRequest {
  ExportArn: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface ExecutionReference {
  ExecutionId: string | undefined;
  ExecutionStatus: ExecutionStatus | undefined;
}
export interface ListExecutionsResponse {
  Executions?: ExecutionReference[];
  NextToken?: string;
}
export interface ListExportsRequest {
  MaxResults?: number;
  NextToken?: string;
}
export interface ExportReference {
  ExportArn: string | undefined;
  ExportName: string | undefined;
  ExportStatus: ExportStatus | undefined;
}
export interface ListExportsResponse {
  Exports?: ExportReference[];
  NextToken?: string;
}
export interface ListTablesRequest {
  NextToken?: string;
  MaxResults?: number;
}
export interface TablePropertyDescription {
  Name?: string;
  ValidValues?: string[];
  DefaultValue?: string;
  Description?: string;
}
export interface Table {
  TableName?: string;
  Description?: string;
  TableProperties?: TablePropertyDescription[];
}
export interface ListTablesResponse {
  Tables?: Table[];
  NextToken?: string;
}
export interface ListTagsForResourceRequest {
  ResourceArn: string | undefined;
  MaxResults?: number;
  NextToken?: string;
}
export interface ListTagsForResourceResponse {
  ResourceTags?: ResourceTag[];
  NextToken?: string;
}
export interface TagResourceRequest {
  ResourceArn: string | undefined;
  ResourceTags: ResourceTag[] | undefined;
}
export interface TagResourceResponse {}
export interface UntagResourceRequest {
  ResourceArn: string | undefined;
  ResourceTagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateExportRequest {
  ExportArn: string | undefined;
  Export: Export | undefined;
}
export interface UpdateExportResponse {
  ExportArn?: string;
}
